{% extends "includes/skeleton_archive.html" %}

{% macro seo_title() %}{{ tr('Tag') }}: {{ tag_name }} - {{ fp(config.site_name) }}{% endmacro %}
{% block title %}{{ seo_title() }}{% endblock title %}
{% block og_title %}{{ seo_title() }}{% endblock %}
{% block og_description %}{{ seo_title() }}{% endblock %}
{% block og_url %}{{ Router.gen_permalink('tag', tag_name, current_page) }}{% endblock %}
{% block twitter_title %}{{ seo_title() }}{% endblock %}

{% block more_section %}

<section id="ga-archive_list" class="ga-section" data-title="#{{- tag_name -}}">
    <ul>
        {% for content in content_list %}
        <li>
            <h1><a target="_self" class="ga-highlight" href="{{ Router.gen_permalink_by_content(content) }}">{{ content.meta['title'] }}</a></h1>
            <time class="ga-mono" datetime="{{ content.meta['date'] }}">
                {{ content.meta['date'].format("YYYY-MM-DD") }}
            </time>
        </li>
        {% endfor %}
    </ul>
</section>

<section class="ga-section ga-mono" id="ga-pager">
    {% if current_page > 1 %}
        <a prev class="ga-highlight" href="{{ Router.gen_permalink('tag', tag_name, current_page-1) }}">Prev</a>
    {% endif %}
    <span>Page {{ current_page }} of {{ max_pages }}</span>
    {% if current_page < max_pages %}
        <a next class="ga-highlight" href="{{ Router.gen_permalink('tag', tag_name, current_page+1) }}">Next</a>
    {% endif %}
</section>

{% endblock more_section %}