<!DOCTYPE HTML>
<html lang="{{ config.language }}">
    <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="renderer" content="webkit">
    <meta name="HandheldFriendly" content="true">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <meta name="keywords" content="{{ ','.join(config.key_words) }}" />
    <meta name="generator" content="{{ maverick_version }}" />
    <meta name="template" content="Galileo" />
    <link rel="alternate" type="application/rss+xml" title="{{ fp(config.site_name) }} &raquo; RSS 2.0" href="{{ fp(config.site_prefix) }}feed/index.xml" />
    <link rel="alternate" type="application/atom+xml" title="{{ fp(config.site_name) }} &raquo; ATOM 1.0" href="{{ fp(config.site_prefix) }}feed/atom/index.xml" />
    <link rel="stylesheet" href="{{ Router.gen_static_file_prefix() }}assets/galileo-8d8763e752.css">
    <link rel="stylesheet" href="{{ Router.gen_static_file_prefix() }}assets/ExSearch/ExSearch-182e5a8868.css">
    <link rel="stylesheet" href="{{ Router.gen_static_file_prefix() }}assets/katex.min.css">
    <link href="https://fonts.googleapis.com/css?family=Fira+Code&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Droid+Serif:400,700&display=swap">
    <script>
        var ExSearchConfig = {
            root: "",
            api: "{{ Router.gen_static_file_prefix() + search_cache_hash }}.json"
        }
    </script>
    {% block head %}{% endblock %}

    {{ fp(config.head_addon) }}
    </head>
    
    <body>
        {% if config.background_img != "" %}
            <div id="bg" style="background-image: url({{ fp(config.background_img) }})"></div>
        {% endif %}
        <div class="container">
            <header id="ga-header">
                <div first>
                    <aside id="ga-brand">
                        <h1 class="brand"><a class="no-style" href="{{ fp(config.site_prefix) }}">{{ fp(config.site_name) }}</a></h1>
                        <p>{{ fp(config.description) }}</p>
                    </aside>
                </div>
                <div second id="ga-nav">
                    <nav class="navs">
                        {{ build_navs(config.nav) }}
                    </nav>
                </div>
            </header>
            <div class="wrapper">
                {% block main %}{% endblock %}
                <footer class="ga-mono" id="ga-footer">
                    <section>
                        <span id="ga-uptime"></span>
                        <span class="brand">{{ fp(config.site_name) }}</span>
                    </section>

                    <script>
                        var site_build_date = "{{ fp(config.site_build_date) }}"
                    </script>
                    <script src="{{ Router.gen_static_file_prefix() }}assets/galileo-7c8cea54ab.js"></script>
                </footer>
            </div>
        </div>
    </div>

    <!--katex-->
    <script defer src="{{ Router.gen_static_file_prefix() }}assets/katex.min.js"></script>
    <script>
    mathOpts = {
        delimiters: [
            {left: "$$", right: "$$", display: true},
            {left: "\\[", right: "\\]", display: true},
            {left: "$", right: "$", display: false},
            {left: "\\(", right: "\\)", display: false}
        ]
    };
    </script>
    <script defer src="{{ Router.gen_static_file_prefix() }}assets/auto-render.min.js" onload="renderMathInElement(document.body, mathOpts);"></script>

    <script src="{{ Router.gen_static_file_prefix() }}assets/ExSearch/jquery.min.js"></script>
    <script src="{{ Router.gen_static_file_prefix() }}assets/ExSearch/ExSearch-493cb9cd89.js"></script>

    {{ fp(config.body_addon) }}
    </body>
</html>