{% extends "includes/skeleton.html" %}

{% block head %}
<title>{% block title %}{% endblock %}</title>
<meta name="author" content="{{ fp(config.author) }}" />
<meta name="description" content="{{ fp(config.description) }}" />
<meta property="og:title" content="{% block og_title %}{% endblock %}" />
<meta property="og:description" content="{{ fp(config.description) }}" />
<meta property="og:site_name" content="{{ fp(config.site_name) }}" />
<meta property="og:type" content="website" />
<meta property="og:url" content="{% block og_url %}{% endblock %}" />
<meta property="og:image" content="{{ fp(config.site_name) }}" />
<meta name="twitter:title" content="{% block twitter_title %}{% endblock %}" />
<meta name="twitter:description" content="{{ fp(config.description) }}" />
<meta name="twitter:card" content="summary" />
<meta name="twitter:image" content="{{ fp(config.site_logo) }}" />
{% endblock head %}

{% block main %}
<main>    
    {% block more_section %}{% endblock more_section %}
</main>
{% endblock main %}
