{% extends "includes/skeleton_content.html" %}

{% block more_section %}
<section id="ga-content_pager">
{% if not content_next is none %}
    <div class="next">
        <a class="ga-highlight" href="{{ Router.gen_permalink_by_content(content_next) }}">{{ content_next.get_meta('title') }}</a>
        <p class="yue">{{ content_next.excerpt }}</p>
    </div>
{% else %}
    <div class="next">
        <h3>{{ tr('No More') }}</h3>
        <p class="yue">{{ tr('This is the latest one.') }}</p>
    </div>
{% endif %}
{% if not content_prev is none %}
    <div class="prev">
        <a class="ga-highlight" href="{{ Router.gen_permalink_by_content(content_prev) }}">{{ content_prev.get_meta('title') }}</a>
        <p class="yue">{{ content_prev.excerpt }}</p>
    </div>
{% else %}
    <div class="prev">
        <h3>{{ tr('No More') }}</h3>
        <p class="yue">{{ tr('This is the oldest one.') }}</p>
    </div>
{% endif %}
</section>
{% endblock more_section %}

{% block more_content -%}
<div id="ga-tags">
    {% for tag in content.get_meta('tags') %}
    <span class="ga-tag">
        <a class="ga-highlight" href="{{ Router.gen_permalink('tag', tag, 1) }}">#{{- tag -}}</a>
    </span>
    {% endfor %}
</div>

{%- endblock more_content %}